==> formbuilder-hamfekran-1.0.6.tgz: package/main.ts <==
export class formBuild {

  static formOperator(obj: ControlModel[]) {
    const form = obj.map((item, index) => {
      return `<div>${makeElement(item, index)}</div>`
    });
    return `${form.join('\n')}<div><button type="submit">ذخیره</button></div>`;
  }

  static getFormValue(form: HTMLElement | null) {
    const value: any = {};
    if (form) {
      const elms = form.getElementsByTagName('input');
      for (let i = 0; i < elms.length; i++) {
        value[i] = elms[i].value;
      }
      return value;
    }
  };
}

const makeElement = (item: ControlModel, index: number) => {
  switch (item.type) {
    case inputType.INPUT:
      return `<label><span>${item.label}</span><input placeholder="${item.placeholder || ''}" /></label>`;

    case inputType.TEXT_AREA:
      return `<label><span>${item.label}</span><textarea placeholder="${item.placeholder || ''}" ></textarea></label>`;

    case inputType.DESCRIPTION:
      return `<label><span>${item.label}</span><textarea placeholder="${item.placeholder || ''}" ></textarea></label>`;

    case inputType.NUMBER:
      return `<label><span>${item.label}</span><input type="number" placeholder="${item.placeholder || ''}"/></label>`;

    case inputType.IMAGE:
      return `<label><span>${item.label}</span><input type="file" placeholder="${item.placeholder || ''}" ></label>`;

    case inputType.FILE:
      return `<label><span>${item.label}</span><input type="file" placeholder="${item.placeholder || ''}" ></label>`;

    case inputType.RADIO:
      return `<label><span>${item.label}</span>
              ${item.options.map((i, indx) => {
        return `<input type="radio" name="radio" id="radio${index}"><label for="radio${index}">${i.label}</label>`;
      }).join('\n')}</label>`;

    case inputType.CHECKBOX:
      return `<label><span>${item.label}</span>
              ${item.options.map((i, indx) => {
        return `<input type="checkbox" name="radio" id="check${indx}"><label for="check${indx}">${i.label}</label>`;
      }).join('\n')}</label>`;

    case inputType.SELECT:
      return `<label><span>${item.label}</span><select>
                <option disabled selected>${item.placeholder || item.label}</option>
              ${item.options.map(i => {
        return `<option>${i.label}</option>`;
      })}</select></label>`;

    default:
      return '';
  }

};

interface ControlModel {
  index: number;
  label: string;
  placeholder: string;
  type: string;
  options: Option[];
  validators: ValidatorsModel;
}

interface Option {
  label: string;
}

interface ValidatorsModel {
  required?: boolean
  minLength?: string;
  maxLength?: string;
  min?: string;
  max?: string;
}

const inputType = {
  INPUT: 'input',
  TEXT_AREA: 'text-area',
  DESCRIPTION: 'description',
  IMAGE: 'image',
  FILE: 'file',
  RADIO: 'radio',
  CHECKBOX: 'checkbox',
  SELECT: 'select',
  PLATE: 'plate-cartex-',
  NATIONAL_ID: 'nationalId',
  NUMBER: 'number',
  PHONE: 'phone',
  EMAIL: 'email',
  POSTAL_CODE: 'postalCode',
  SHEBA: 'sheba',
  DATE_SH: 'dateShamsi',
  LOCATION: 'location',
  PAYMENT_RIAL: 'paymentRial',
};

==> formbuilder-hamfekran-1.0.7.tgz: package/main.ts <==
export function FormOperator(obj: ControlModel[]) {
  const form = obj.map((item, index) => {
    return `<div>${makeElement(item, index)}</div>`
  });
  return `${form.join('\n')}<div><button type="submit">ذخیره</button></div>`;
}

export function GetFormValue(form: HTMLElement | null) {
  const value: any = {};
  if (form) {
    const elms = form.getElementsByTagName('input');
    for (let i = 0; i < elms.length; i++) {
      value[i] = elms[i].value;
    }
    return value;
  }
}

const makeElement = (item: ControlModel, index: number) => {
  switch (item.type) {
    case inputType.INPUT:
      return `<label><span>${item.label}</span><input placeholder="${item.placeholder || ''}" /></label>`;

    case inputType.TEXT_AREA:
      return `<label><span>${item.label}</span><textarea placeholder="${item.placeholder || ''}" ></textarea></label>`;

    case inputType.DESCRIPTION:
      return `<label><span>${item.label}</span><textarea placeholder="${item.placeholder || ''}" ></textarea></label>`;

    case inputType.NUMBER:
      return `<label><span>${item.label}</span><input type="number" placeholder="${item.placeholder || ''}"/></label>`;

    case inputType.IMAGE:
      return `<label><span>${item.label}</span><input type="file" placeholder="${item.placeholder || ''}" ></label>`;

    case inputType.FILE:
      return `<label><span>${item.label}</span><input type="file" placeholder="${item.placeholder || ''}" ></label>`;

    case inputType.RADIO:
      return `<label><span>${item.label}</span>
              ${item.options.map((i, indx) => {
        return `<input type="radio" name="radio" id="radio${index}"><label for="radio${index}">${i.label}</label>`;
      }).join('\n')}</label>`;

    case inputType.CHECKBOX:
      return `<label><span>${item.label}</span>
              ${item.options.map((i, indx) => {
        return `<input type="checkbox" name="radio" id="check${indx}"><label for="check${indx}">${i.label}</label>`;
      }).join('\n')}</label>`;

    case inputType.SELECT:
      return `<label><span>${item.label}</span><select>
                <option disabled selected>${item.placeholder || item.label}</option>
              ${item.options.map(i => {
        return `<option>${i.label}</option>`;
      })}</select></label>`;

    default:
      return '';
  }

};

interface ControlModel {
  index: number;
  label: string;
  placeholder: string;
  type: string;
  options: Option[];
  validators: ValidatorsModel;
}

interface Option {
  label: string;
}

interface ValidatorsModel {
  required?: boolean
  minLength?: string;
  maxLength?: string;
  min?: string;
  max?: string;
}

const inputType = {
  INPUT: 'input',
  TEXT_AREA: 'text-area',
  DESCRIPTION: 'description',
  IMAGE: 'image',
  FILE: 'file',
  RADIO: 'radio',
  CHECKBOX: 'checkbox',
  SELECT: 'select',
  PLATE: 'plate-cartex-',
  NATIONAL_ID: 'nationalId',
  NUMBER: 'number',
  PHONE: 'phone',
  EMAIL: 'email',
  POSTAL_CODE: 'postalCode',
  SHEBA: 'sheba',
  DATE_SH: 'dateShamsi',
  LOCATION: 'location',
  PAYMENT_RIAL: 'paymentRial',
};
